DataleonConfig class

Constructors

DataleonConfig({required String sessionId, required String token, String? accountTenant, String? uploadBucket, String appVersion = '2.0.10', String? initialLanguage, String customerAssetsBucket = 'yap-assets-customer'})

Properties

accountTenant String?
final
accountTenantHeader String?
no setter
appVersion String
final
baseUrl String
Base URL for API calls. Hardcoded for security; cannot be overridden.
no setter
customerAssetsBucket String
final
hashCode int
The hash code for this object.
no setterinherited
initialLanguage String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
sessionToken String
no setter
token String
final
uploadBucket String?
final

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited