DataleonFlowStep enum

Inheritance
Available extensions

Values

loading → const DataleonFlowStep
alreadyProcessed → const DataleonFlowStep
error → const DataleonFlowStep
welcome → const DataleonFlowStep
cameraPermission → const DataleonFlowStep
documentType → const DataleonFlowStep
documentCountry → const DataleonFlowStep
document → const DataleonFlowStep
selfie → const DataleonFlowStep
review → const DataleonFlowStep
submitting → const DataleonFlowStep
success → const DataleonFlowStep

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DataleonFlowStep>
A constant List of the values in this enum, in order of their declaration.