DataleonStepResult class

Constructors

DataleonStepResult({required String stepName, required bool success, Map<String, dynamic>? data, String? errorMessage})
const

Properties

data Map<String, dynamic>?
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepName String
final
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited