DataleonApiService class

Constructors

DataleonApiService({required DataleonConfig config, Client? client})

Properties

config DataleonConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyRequestService({required String path, required Object data, Map<String, String>? headers}) Future<Map<String, dynamic>>
completeSession() Future<void>
Complete / finalize the session.
dispose() → void
fetchRequestConfig() Future<Map<String, dynamic>>
Fetch the request configuration and progress from the backend. Equivalent to the React fetchRequestConfig.
fetchToken() Future<Map<String, dynamic>>
Fetch a JWT token for the session from the backend. Called once at startup before any other API call.
generateSignedUploadUrl({required String objectName, required String contentType, String acl = 'private', String? bucket}) Future<Map<String, dynamic>>
getSession() Future<DataleonSession>
Fetch the current session info from the backend.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendCaptureFrame({required Map<String, dynamic> payload}) Future<Map<String, dynamic>>
submitFinishedDocuments({required Object data}) Future<Map<String, dynamic>>
submitStep({required String stepName, required Map<String, dynamic> data}) Future<Map<String, dynamic>>
Submit step data to the backend.
toString() String
A string representation of this object.
inherited
uploadBytesToSignedUrl({required String signedUrl, required List<int> bytes, required String contentType}) Future<String>
uploadFile({required String stepName, required String fieldName, required List<int> fileBytes, required String fileName}) Future<Map<String, dynamic>>
Upload a file (document photo, selfie, etc.) to the backend.

Operators

operator ==(Object other) bool
The equality operator.
inherited