DataleonConfig class

Constructors

DataleonConfig({required String sessionId, required String apiKey, String? apiBaseUrl, String? uploadBucket, String appVersion = '2.0.0-beta'})

Properties

apiBaseUrl String?
final
apiKey String
final
appVersion String
final
baseUrl String
Base URL for API calls.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
sessionToken String
The JWT session token. Must be set via setSessionToken before API calls.
getter/setter pair
uploadBucket String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited