DataleonFlowController class

Inheritance

Constructors

DataleonFlowController({required DataleonConfig config, DataleonApiService? apiService, List<DataleonFlowStep>? steps})

Properties

apiService DataleonApiService
no setter
config DataleonConfig
no setter
configErrorMessage String?
no setter
currentIndex int
no setter
currentStep DataleonFlowStep
no setter
dashboardConfiguration Map<String, dynamic>
no setter
documentCountry String?
no setter
documentType String?
no setter
formSteps List<Map<String, dynamic>>
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isLastStep bool
no setter
isLoading bool
no setter
languageCode String
no setter
progress double
no setter
requestConfig Map<String, dynamic>?
no setter
requestResult Map<String, dynamic>
no setter
result DataleonResult
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedCustomDocument Map<String, dynamic>?
no setter
stepResults Map<DataleonFlowStep, DataleonStepResult>
no setter
steps List<DataleonFlowStep>
no setter
uploadedFiles Map<String, Map<String, String>>
no setter
webviewConfig Map<String, dynamic>
no setter
workspace Map<String, dynamic>?
no setter

Methods

abort() → void
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
cancel() → void
clearUploadedFiles() → void
completeSession() Future<void>
Complete the session on the backend and mark the flow as finished.
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
override
fail([String? error]) → void
fetchConfig() Future<void>
Fetch the request configuration from the backend and advance to the welcome step once loaded.
finish() → void
formStepForAction(String action) Map<String, dynamic>?
goToStep(DataleonFlowStep step) → void
hasWorldCountryForDocType(String? docType) bool
nextStep() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
previousStep() → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
saveStepResult(DataleonFlowStep step, DataleonStepResult result) → void
Save an intermediate step result locally.
saveUploadedFile({required String phase, required String url, required String name, required String key}) → void
selectDocumentCountry(String? documentCountry) → void
selectDocumentType(String documentType, {Map<String, dynamic>? customDocument}) → void
setError(String error) → void
setLanguage(String languageCode) → void
setLoading(bool value) → void
start() → void
submitStepData({required String stepName, required Map<String, dynamic> data}) Future<Map<String, dynamic>>
Submit the current step data to the backend API.
toString() String
A string representation of this object.
inherited
updateProgress(double value) → void
uploadFile({required String stepName, required String fieldName, required List<int> fileBytes, required String fileName}) Future<Map<String, dynamic>>
Upload a file to the backend for the given step.

Operators

operator ==(Object other) bool
The equality operator.
inherited